Interface: ArcProps | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: ArcProps

## # Properties

### # circumference

• circumference: `number`

#### # Defined in

index.esm.d.ts:1718
(opens new window)

### # endAngle

• endAngle: `number`

#### # Defined in

index.esm.d.ts:1715
(opens new window)

### # innerRadius

• innerRadius: `number`

#### # Defined in

index.esm.d.ts:1716
(opens new window)

### # outerRadius

• outerRadius: `number`

#### # Defined in

index.esm.d.ts:1717
(opens new window)

### # startAngle

• startAngle: `number`

#### # Defined in

index.esm.d.ts:1714
(opens new window)

### # x

• x: `number`

#### # Defined in

index.esm.d.ts:1712
(opens new window)

### # y

• y: `number`

#### # Defined in

index.esm.d.ts:1713
(opens new window)